# ControllerModeling

Overview
Best practice is to follow the example in the notebook:
controllers/Notebooks/Example_NoSlack.ipynb

The goal of this package is to:

Fit continuous controllers of a proportional-integral nature.
Estimate the mixing coefficient that determines how each controller contributes to the actor's control at each moment ( t ).